@@ -935,7 +935,7 @@ static void
 fr_command_tar_handle_error (FrCommand   *comm,
 			     FrProcError *error)
 {
-	if (error->type == FR_PROC_ERROR_COMMAND_ERROR) {
+	if (error->type != FR_PROC_ERROR_NONE) {
 		if (error->status <= 1)
 			error->type = FR_PROC_ERROR_NONE;
 	}
@@ -963,47 +963,48 @@ fr_command_tar_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_tar_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
 
 	/* In solaris gtar is present under /usr/sfw/bin */
-	if (! is_program_in_path ("tar") && ! is_program_in_path ("/usr/sfw/bin/gtar"))
+	if (! is_program_available ("tar", check_command) && ! is_program_available ("/usr/sfw/bin/gtar", check_command))
 		return capabilities;
 
 	if (is_mime_type (mime_type, "application/x-tar")) {
 		capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-compressed-tar")) {
-		if (is_program_in_path ("gzip"))
+		if (is_program_available ("gzip", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-bzip-compressed-tar")) {
-		if (is_program_in_path ("bzip2"))
+		if (is_program_available ("bzip2", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-tarz")) {
-		if (is_program_in_path ("compress") && is_program_in_path ("uncompress"))
+		if (is_program_available ("compress", check_command) && is_program_available ("uncompress", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
-		else if (is_program_in_path ("gzip"))
+		else if (is_program_available ("gzip", check_command))
 			capabilities |= FR_COMMAND_CAN_READ;
 	}
 	else if (is_mime_type (mime_type, "application/x-lzip-compressed-tar")) {
-		if (is_program_in_path ("lzip"))
+		if (is_program_available ("lzip", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-lzma-compressed-tar")) {
-		if (is_program_in_path ("lzma"))
+		if (is_program_available ("lzma", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-xz-compressed-tar")) {
-		if (is_program_in_path ("xz"))
+		if (is_program_available ("xz", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-lzop-compressed-tar")) {
-		if (is_program_in_path ("lzop"))
+		if (is_program_available ("lzop", check_command))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
 	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar")) {
@@ -1011,7 +1012,7 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 		int   i;
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
-			if (is_program_in_path (try_command[i])) {
+			if (is_program_available (try_command[i], check_command)) {
 				capabilities |= FR_COMMAND_CAN_WRITE;
 				break;
 			}
@@ -1044,6 +1045,33 @@ fr_command_tar_set_mime_type (FrCommand  *comm,
 }
 
 
+static const char *
+fr_command_tar_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	if (is_mime_type (mime_type, "application/x-tar"))
+		return "tar";
+	else if (is_mime_type (mime_type, "application/x-compressed-tar"))
+		return "tar,gzip";
+	else if (is_mime_type (mime_type, "application/x-bzip-compressed-tar"))
+		return "tar,bzip2";
+	else if (is_mime_type (mime_type, "application/x-tarz"))
+		return "tar,gzip,ncompress";
+	else if (is_mime_type (mime_type, "application/x-lzip-compressed-tar"))
+		return "tar,lzip";
+	else if (is_mime_type (mime_type, "application/x-lzma-compressed-tar"))
+		return "tar,lzma";
+	else if (is_mime_type (mime_type, "application/x-xz-compressed-tar"))
+		return "tar,xz";
+	else if (is_mime_type (mime_type, "application/x-lzop-compressed-tar"))
+		return "tar,lzop";
+	else if (is_mime_type (mime_type, "application/x-7z-compressed-tar"))
+		return "tar,p7zip";
+
+	return NULL;
+}
+
+
 static void
 fr_command_tar_class_init (FrCommandTarClass *class)
 {
@@ -1065,6 +1093,7 @@ fr_command_tar_class_init (FrCommandTarClass *class)
 	afc->set_mime_type    = fr_command_tar_set_mime_type;
 	afc->recompress       = fr_command_tar_recompress;
 	afc->uncompress       = fr_command_tar_uncompress;
+	afc->get_packages     = fr_command_tar_get_packages;
 }
 
 
