@@ -222,9 +222,7 @@ process_zoo_line (char     *line,
 static void
 fr_command_zoo_list (FrCommand  *zoo_comm)
 {
-	fr_process_set_out_line_func (FR_COMMAND (zoo_comm)->process,
-				      process_zoo_line,
-				      zoo_comm);
+	fr_process_set_out_line_func (zoo_comm->process, process_zoo_line, zoo_comm);
 
 	fr_process_begin_command (zoo_comm->process, "zoo");
 	fr_process_add_arg (zoo_comm->process, "lq");
@@ -334,18 +332,27 @@ fr_command_zoo_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_zoo_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("zoo"))
+	if (is_program_available ("zoo", check_command))
 		capabilities |= FR_COMMAND_CAN_READ_WRITE;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_zoo_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return "zoo";
+}
+
+
 static void
 fr_command_zoo_class_init (FrCommandZooClass *class)
 {
@@ -364,6 +371,7 @@ fr_command_zoo_class_init (FrCommandZooClass *class)
 	afc->test             = fr_command_zoo_test;
 	afc->get_mime_types   = fr_command_zoo_get_mime_types;
 	afc->get_capabilities = fr_command_zoo_get_capabilities;
+	afc->get_packages     = fr_command_zoo_get_packages;
 }
 
 
